==> haskell-kan-extensions-5.0.1-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-kan-extensions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-9d0c832e36b69937523b7bdb128f89cd
key: kanex_KJsVk7iSyOOBfHaV6JVpkv
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-KJsVk7iSyOOBfHaV6JVpkv
depends:
    adjunctions-4.3-c475a106420800be166b9b6982c59446
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-e98e7adc8875accf64a86529d9aeae51
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
    free-4.12.4-a5ffddbbf41dcb5e4b11e5d62a21f456
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.0.1-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-kan-extensions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.0.1
id: kan-extensions-5.0.1-76348eb8b9558b599268f83ff585a869
key: kanex_KIpHhFdWsK8Eb9nTmdh49U
license: BSD3
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads
category: Data Structures, Monads, Comonads, Functors
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Day Data.Functor.Contravariant.Yoneda
    Data.Functor.Contravariant.Coyoneda Data.Functor.Day
    Data.Functor.Day.Curried Data.Functor.Kan.Lan Data.Functor.Kan.Ran
    Data.Functor.Yoneda Data.Functor.Coyoneda
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/kan-extensions-5.0.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/kan-extensions-5.0.1
hs-libraries: HSkan-extensions-5.0.1-KIpHhFdWsK8Eb9nTmdh49U
depends:
    adjunctions-4.3-51e7d4a24d361113244a76d085504c45
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-3b2e208311908bc5a9db1ceb26126917
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
